import click
from max_ard.commands.storage import storage
from max_ard.commands.grid import cell
from max_ard.commands.tile import tile
from max_ard.commands.select import select
from max_ard.commands.grid import cell
from max_ard.commands.order import order
from max_ard.session import write_config, get_session, read_token

@click.group()
def max_ard():
    '''Maxar ARD tools'''
    pass


@click.command()
@click.option('--username', help='ARD username')
@click.option('--password', help='ARD password')
def login(username, password):
    ''' Creates credential file using passed options --username and --password and tests access 
        to the ARD system. If run without options, 
        will only check if existing credential file at ~/.ard-config contains valid credentials '''

    if username or password:
        print("... Creating config file ~/.ard-config")
        write_config(username, password)
    try:
        print('... Checking access')
        get_session()
    except:
        raise
    print('ARD access confirmed')

@click.command()
def token():
    ''' Returns the current token. 

        Handy for substitution in bash commands like curl:

            \b
            curl -H 'Accept: application/json' \\
                 -H "Authorization: Bearer $(max_ard token)" \\
                 https://hostname/api/myresource
    '''

    try:
        get_session()
    except:
        raise
    return read_token()


max_ard.add_command(login)
max_ard.add_command(token)


max_ard.add_command(storage)
max_ard.add_command(cell)
#max_ard.add_command(tile)
max_ard.add_command(cell)
max_ard.add_command(select)
max_ard.add_command(order)

if __name__ == '__main__':
    max_ard()